@@ -20,21 +20,23 @@ from twisted.web.template import Element, TagLoader
 from ._app import _call
 from ._decorators import bindable, modified, originalName
 
-if TYPE_CHECKING:               # pragma: no cover
+if TYPE_CHECKING:  # pragma: no cover
     from twisted.internet.defer import Deferred
     from twisted.web.iweb import IRequest
     from twisted.web.template import Tag
     from typing import List
+
     Deferred, IRequest, Tag
     StackType = List[Tuple[Any, Callable[[Any], None]]]
 
 # https://github.com/python/mypy/issues/224
 ATOM_TYPES = (
-    cast(Tuple[Any, ...], integer_types) +
-    cast(Tuple[Any, ...], string_types) +
-    cast(Tuple[Any, ...], (float, None.__class__))
+    cast(Tuple[Any, ...], integer_types)
+    + cast(Tuple[Any, ...], string_types)
+    + cast(Tuple[Any, ...], (float, None.__class__))
 )
 
+
 def _should_return_json(request):
     # type: (IRequest) -> bool
     """
@@ -75,10 +77,12 @@ def resolveDeferredObjects(root):
             parent = [None] * len(obj)  # type: Any
             setter(parent)
             stack.extend(
-                reversed([
-                    (child, partial(setitem, parent, i))
-                    for i, child in enumerate(obj)
-                ])
+                reversed(
+                    [
+                        (child, partial(setitem, parent, i))
+                        for i, child in enumerate(obj)
+                    ]
+                )
             )
         elif isinstance(obj, tuple):
             parent = [None] * len(obj)
@@ -89,10 +93,12 @@ def resolveDeferredObjects(root):
                 setter(tuple(parent))
 
             stack.extend(
-                reversed([
-                    (child, partial(setTupleItem, i))
-                    for i, child in enumerate(obj)
-                ])
+                reversed(
+                    [
+                        (child, partial(setTupleItem, i))
+                        for i, child in enumerate(obj)
+                    ]
+                )
             )
         elif isinstance(obj, dict):
             parent = {}
@@ -111,14 +117,12 @@ def resolveDeferredObjects(root):
             stack.append((obj._asJSON(), setter))
         else:
             raise TypeError(
-                obj,
-                "{input} not JSON serializable".format(input=obj),
+                obj, "{input} not JSON serializable".format(input=obj),
             )
 
     returnValue(result[0])
 
 
-
 def _extra_types(input):
     """
     Renderability for a few additional types.
@@ -128,15 +132,15 @@ def _extra_types(input):
     return input
 
 
-
 class PlatedElement(Element):
     """
     The element type returned by L{Plating}.  This contains several utility
     renderers.
     """
 
-    def __init__(self, slot_data, preloaded, boundInstance, presentationSlots,
-                 renderers):
+    def __init__(
+        self, slot_data, preloaded, boundInstance, presentationSlots, renderers
+    ):
         """
         @param slot_data: A dictionary mapping names to values.
 
@@ -147,12 +151,13 @@ class PlatedElement(Element):
         self._presentationSlots = presentationSlots
         self._renderers = renderers
         super(PlatedElement, self).__init__(
-            loader=TagLoader(preloaded.fillSlots(
-                **{k: _extra_types(v) for k, v in slot_data.items()}
-            ))
+            loader=TagLoader(
+                preloaded.fillSlots(
+                    **{k: _extra_types(v) for k, v in slot_data.items()}
+                )
+            )
         )
 
-
     def _asJSON(self):
         """
         Render this L{PlatedElement} as JSON-serializable data.
@@ -162,7 +167,6 @@ class PlatedElement(Element):
             json_data.pop(ignored, None)
         return json_data
 
-
     def lookupRenderMethod(self, name):
         """
         @return: a renderer.
@@ -173,8 +177,10 @@ class PlatedElement(Element):
             @modified("plated render wrapper", wrapped)
             def renderWrapper(request, tag, *args, **kw):
                 # type: (IRequest, Tag, *Any, **Any) -> Any
-                return _call(self._boundInstance, wrapped,
-                             request, tag, *args, **kw)
+                return _call(
+                    self._boundInstance, wrapped, request, tag, *args, **kw
+                )
+
             return renderWrapper
         if ":" not in name:
             raise MissingRenderMethod(self, name)
@@ -183,6 +189,7 @@ class PlatedElement(Element):
         def renderList(request, tag):
             for item in self.slot_data[slot]:
                 yield tag.fillSlots(item=_extra_types(item))
+
         types = {
             "list": renderList,
         }
@@ -192,7 +199,6 @@ class PlatedElement(Element):
             raise MissingRenderMethod(self, name)
 
 
-
 class Plating(object):
     """
     A L{Plating} is a container which can be used to generate HTML from data.
@@ -202,8 +208,7 @@ class Plating(object):
 
     CONTENT = "klein:plating:content"
 
-    def __init__(self, defaults=None, tags=None,
-                 presentation_slots=()):
+    def __init__(self, defaults=None, tags=None, presentation_slots=()):
         """
         """
         self._defaults = {} if defaults is None else defaults
@@ -211,7 +216,6 @@ class Plating(object):
         self._presentationSlots = {self.CONTENT} | set(presentation_slots)
         self._renderers = {}
 
-
     def renderMethod(self, renderer):
         """
         Add a render method to this L{Plating} object that can be used in the
@@ -223,10 +227,10 @@ class Plating(object):
         self._renderers[text_type(originalName(renderer))] = renderer
         return renderer
 
-
     def routed(self, routing, tags):
         """
         """
+
         def mydecorator(method):
             loader = TagLoader(tags)
 
@@ -241,22 +245,26 @@ class Plating(object):
                     json_data.update(data)
                     for ignored in self._presentationSlots:
                         json_data.pop(ignored, None)
-                    text_type = u'json'
+                    text_type = u"json"
                     ready = yield resolveDeferredObjects(json_data)
                     result = dumps(ready)
                 else:
                     data[self.CONTENT] = loader.load()
-                    text_type = u'html'
+                    text_type = u"html"
                     result = self._elementify(instance, data)
                 request.setHeader(
-                    b'content-type', (u'text/{format}; charset=utf-8'
-                                      .format(format=text_type)
-                                      .encode("charmap"))
+                    b"content-type",
+                    (
+                        u"text/{format}; charset=utf-8".format(
+                            format=text_type
+                        ).encode("charmap")
+                    ),
                 )
                 returnValue(result)
-            return method
-        return mydecorator
 
+            return method
+
+        return mydecorator
 
     def _elementify(self, instance, to_fill_with):
         """
@@ -266,11 +274,13 @@ class Plating(object):
         slot_data.update(to_fill_with)
         [loaded] = self._loader.load()
         loaded = loaded.clone()
-        return PlatedElement(slot_data=slot_data,
-                             preloaded=loaded,
-                             renderers=self._renderers,
-                             boundInstance=instance,
-                             presentationSlots=self._presentationSlots)
+        return PlatedElement(
+            slot_data=slot_data,
+            preloaded=loaded,
+            renderers=self._renderers,
+            boundInstance=instance,
+            presentationSlots=self._presentationSlots,
+        )
 
     @attr.s
     class _Widget(object):
@@ -283,7 +293,8 @@ class Plating(object):
         instance's L{Plating._elementify} to construct a
         L{PlatedElement}.
         """
-        _plating = attr.ib(type='Plating')
+
+        _plating = attr.ib(type="Plating")
         _function = attr.ib(type=Callable[..., Any])
         _instance = attr.ib(type=object)
 
@@ -304,11 +315,9 @@ class Plating(object):
             data = self._function(*args, **kwargs)
             return self._plating._elementify(self._instance, data)
 
-
         def __getattr__(self, attr):
             return getattr(self._function, attr)
 
-
     def widgeted(self, function):
         """
         A decorator that turns a function into a renderer for an
