@@ -5,6 +5,7 @@ from ._app import (
     resource,
     route,
     run,
+    subroute,
     urlFor,
     url_for,
 )
@@ -17,6 +18,7 @@ __all__ = (
     "resource",
     "route",
     "run",
+    "subroute",
     "urlFor",
     "url_for",
 )
