@@ -5,7 +5,7 @@ import sys
 try:
     from unittest.mock import Mock, patch
 except Exception:
-    from mock import Mock, patch  # type:ignore
+    from mock import Mock, patch  # type:ignore[misc]
 
 from twisted.python.components import registerAdapter
 from twisted.trial import unittest
@@ -18,7 +18,6 @@ from .._decorators import bindable, modified, originalName
 from .._interfaces import IKleinRequest
 
 
-
 class DummyRequest(object):
     def __init__(self, n):
         self.n = n
@@ -27,7 +26,7 @@ class DummyRequest(object):
         return other.n == self.n
 
     def __repr__(self):
-        return '<DummyRequest({n})>'.format(n=self.n)
+        return "<DummyRequest({n})>".format(n=self.n)
 
 
 registerAdapter(KleinRequest, DummyRequest, IKleinRequest)
@@ -37,6 +36,7 @@ class KleinEqualityTestCase(unittest.TestCase, EqualityTestsMixin):
     """
     Tests for L{Klein}'s implementation of C{==} and C{!=}.
     """
+
     class _One(object):
         app = Klein()
 
@@ -59,19 +59,17 @@ class KleinEqualityTestCase(unittest.TestCase, EqualityTestsMixin):
         # equal to everything.
         return self._One().app
 
-
     def anotherInstance(self):
         return self._another
 
 
-
 class DuplicateHasher(object):
     """
     Every L{DuplicateHasher} has the same hash value and compares equal to
     every other L{DuplicateHasher}.
     """
 
-    __slots__ = ('_identifier',)
+    __slots__ = ("_identifier",)
 
     def __init__(self, identifier):
         self._identifier = identifier
@@ -89,7 +87,6 @@ class DuplicateHasher(object):
         return True
 
 
-
 class KleinTestCase(unittest.TestCase):
     def test_route(self):
         """
@@ -107,7 +104,6 @@ class KleinTestCase(unittest.TestCase):
 
         self.assertEqual(app.execute_endpoint("foo", DummyRequest(1)), "foo")
 
-
     def test_mapByIdentity(self):
         """
         Routes are routed to the proper object regardless of its C{__hash__}
@@ -121,11 +117,12 @@ class KleinTestCase(unittest.TestCase):
         d[a] = "test"
         self.assertEqual(d.get(b), "test")
 
-        self.assertEqual(a.myRouter.execute_endpoint("root", DummyRequest(1)),
-                         "a")
-        self.assertEqual(b.myRouter.execute_endpoint("root", DummyRequest(1)),
-                         "b")
-
+        self.assertEqual(
+            a.myRouter.execute_endpoint("root", DummyRequest(1)), "a"
+        )
+        self.assertEqual(
+            b.myRouter.execute_endpoint("root", DummyRequest(1)), "b"
+        )
 
     def test_preserveIdentityWhenPossible(self):
         """
@@ -137,7 +134,8 @@ class KleinTestCase(unittest.TestCase):
         """
         # This is the desirable property.
         class DuplicateHasherWithWritableAttribute(DuplicateHasher):
-            __slots__ = ('__klein_bound_myRouter__',)
+            __slots__ = ("__klein_bound_myRouter__",)
+
         a = DuplicateHasherWithWritableAttribute("a")
         self.assertIs(a.myRouter, a.myRouter)
 
@@ -151,7 +149,6 @@ class KleinTestCase(unittest.TestCase):
         # just not identical.
         self.assertIsNot(b.myRouter, b.myRouter)
 
-
     def test_kleinNotFoundOnClass(self):
         """
         When the Klein object can't find itself on the class it still preserves
@@ -177,7 +174,6 @@ class KleinTestCase(unittest.TestCase):
         self.assertIs(tr.app1, tr.app1)
         self.assertIs(tr.app2, tr.app2)
 
-
     def test_bindInstanceIgnoresBlankProperties(self):
         """
         L{Klein.__get__} doesn't propagate L{AttributeError} when
@@ -196,7 +192,6 @@ class KleinTestCase(unittest.TestCase):
 
         self.assertIsInstance(Oddment().app, Klein)
 
-
     def test_submountedRoute(self):
         """
         L{Klein.subroute} adds functions as routable endpoints.
@@ -204,18 +199,17 @@ class KleinTestCase(unittest.TestCase):
         app = Klein()
 
         with app.subroute("/sub") as app:
+
             @app.route("/prefixed_uri")
             def foo_endpoint(request):
                 return b"foo"
 
         c = app.url_map.bind("sub/prefixed_uri")
+        self.assertEqual(c.match("/sub/prefixed_uri"), ("foo_endpoint", {}))
+        self.assertEqual(len(app.endpoints), 1)
         self.assertEqual(
-            c.match("/sub/prefixed_uri"), ("foo_endpoint", {}))
-        self.assertEqual(
-            len(app.endpoints), 1)
-        self.assertEqual(
-            app.execute_endpoint("foo_endpoint", DummyRequest(1)), b"foo")
-
+            app.execute_endpoint("foo_endpoint", DummyRequest(1)), b"foo"
+        )
 
     def test_stackedRoute(self):
         """
@@ -238,10 +232,7 @@ class KleinTestCase(unittest.TestCase):
         )
 
         self.assertEqual(c.match("/bar"), ("bar", {}))
-        self.assertEqual(
-            app.execute_endpoint("bar", DummyRequest(2)), "foobar"
-        )
-
+        self.assertEqual(app.execute_endpoint("bar", DummyRequest(2)), "foobar")
 
     def test_branchRoute(self):
         """
@@ -257,22 +248,24 @@ class KleinTestCase(unittest.TestCase):
         c = app.url_map.bind("foo")
         self.assertEqual(c.match("/foo/"), ("branchfunc", {}))
         self.assertEqual(
-            c.match("/foo/bar"),
-            ("branchfunc_branch", {'__rest__': 'bar'}))
+            c.match("/foo/bar"), ("branchfunc_branch", {"__rest__": "bar"})
+        )
 
-        self.assertEquals(app.endpoints["branchfunc"].__name__,
-                          "route '/foo/' executor for branchfunc")
+        self.assertEquals(
+            app.endpoints["branchfunc"].__name__,
+            "route '/foo/' executor for branchfunc",
+        )
         self.assertEquals(
             app.endpoints["branchfunc_branch"].__name__,
-            "branch route '/foo/' executor for branchfunc"
+            "branch route '/foo/' executor for branchfunc",
         )
         self.assertEquals(
-            app.execute_endpoint("branchfunc_branch",
-                                 DummyRequest("looking for foo")),
-            "foo"
+            app.execute_endpoint(
+                "branchfunc_branch", DummyRequest("looking for foo")
+            ),
+            "foo",
         )
 
-
     def test_bindable(self):
         """
         L{bindable} is a decorator which allows a function decorated by @route
@@ -300,12 +293,12 @@ class KleinTestCase(unittest.TestCase):
         self.assertEquals(calls, [(None, req), (b, req)])
         self.assertEqual(originalName(method), "method")
 
-
     def test_modified(self):
         """
         L{modified} is a decorator which alters the thing that it decorates,
         and describes itself as such.
         """
+
         def annotate(decoratee):
             decoratee.supersized = True
             return decoratee
@@ -322,7 +315,6 @@ class KleinTestCase(unittest.TestCase):
         self.assertIn("supersizer for add", str(megaAdd))
         self.assertEqual(megaAdd(3, 4), 43000)
 
-
     def test_classicalRoute(self):
         """
         L{Klein.route} may be used a method decorator when a L{Klein} instance
@@ -347,13 +339,13 @@ class KleinTestCase(unittest.TestCase):
         )
         self.assertEqual(bar_calls, [(foo, DummyRequest(1))])
 
-
     def test_classicalRouteWithTwoInstances(self):
         """
         Multiple instances of a class with a L{Klein} attribute and
         L{Klein.route}'d methods can be created and their L{Klein}s used
         independently.
         """
+
         class Foo(object):
             app = Klein()
 
@@ -373,19 +365,19 @@ class KleinTestCase(unittest.TestCase):
         dr1 = DummyRequest(1)
         dr2 = DummyRequest(2)
 
-        foo_1_app.execute_endpoint('bar', dr1)
-        foo_2_app.execute_endpoint('bar', dr2)
+        foo_1_app.execute_endpoint("bar", dr1)
+        foo_2_app.execute_endpoint("bar", dr2)
 
         self.assertEqual(foo_1.bar_calls, [(foo_1, dr1)])
         self.assertEqual(foo_2.bar_calls, [(foo_2, dr2)])
 
-
     def test_classicalRouteWithBranch(self):
         """
         Multiple instances of a class with a L{Klein} attribute and
         L{Klein.route}'d methods can be created and their L{Klein}s used
         independently.
         """
+
         class Foo(object):
             app = Klein()
 
@@ -405,13 +397,12 @@ class KleinTestCase(unittest.TestCase):
         dr1 = DummyRequest(1)
         dr2 = DummyRequest(2)
 
-        foo_1_app.execute_endpoint('bar_branch', dr1)
-        foo_2_app.execute_endpoint('bar_branch', dr2)
+        foo_1_app.execute_endpoint("bar_branch", dr1)
+        foo_2_app.execute_endpoint("bar_branch", dr2)
 
         self.assertEqual(foo_1.bar_calls, [(foo_1, dr1)])
         self.assertEqual(foo_2.bar_calls, [(foo_2, dr2)])
 
-
     def test_branchDoesntRequireTrailingSlash(self):
         """
         L{Klein.route} should create a branch path which consumes all children,
@@ -425,14 +416,14 @@ class KleinTestCase(unittest.TestCase):
             return "foo"
 
         c = app.url_map.bind("foo")
-        self.assertEqual(c.match("/foo/bar"),
-                         ("foo_branch", {"__rest__": "bar"}))
+        self.assertEqual(
+            c.match("/foo/bar"), ("foo_branch", {"__rest__": "bar"})
+        )
 
-
-    @patch('klein._app.KleinResource')
-    @patch('klein._app.Site')
-    @patch('klein._app.log')
-    @patch('klein._app.reactor')
+    @patch("klein._app.KleinResource")
+    @patch("klein._app.Site")
+    @patch("klein._app.log")
+    @patch("klein._app.reactor")
     def test_run(self, reactor, mock_log, mock_site, mock_kr):
         """
         L{Klein.run} configures a L{KleinResource} and a L{Site}
@@ -444,7 +435,8 @@ class KleinTestCase(unittest.TestCase):
         app.run("localhost", 8080)
 
         reactor.listenTCP.assert_called_with(
-            8080, mock_site.return_value, backlog=50, interface="localhost")
+            8080, mock_site.return_value, backlog=50, interface="localhost"
+        )
 
         reactor.run.assert_called_with()
 
@@ -452,11 +444,10 @@ class KleinTestCase(unittest.TestCase):
         mock_kr.assert_called_with(app)
         mock_log.startLogging.assert_called_with(sys.stdout)
 
-
-    @patch('klein._app.KleinResource')
-    @patch('klein._app.Site')
-    @patch('klein._app.log')
-    @patch('klein._app.reactor')
+    @patch("klein._app.KleinResource")
+    @patch("klein._app.Site")
+    @patch("klein._app.log")
+    @patch("klein._app.reactor")
     def test_runWithLogFile(self, reactor, mock_log, mock_site, mock_kr):
         """
         L{Klein.run} logs to the specified C{logFile}.
@@ -467,7 +458,8 @@ class KleinTestCase(unittest.TestCase):
         app.run("localhost", 8080, logFile=logFile)
 
         reactor.listenTCP.assert_called_with(
-            8080, mock_site.return_value, backlog=50, interface="localhost")
+            8080, mock_site.return_value, backlog=50, interface="localhost"
+        )
 
         reactor.run.assert_called_with()
 
@@ -475,11 +467,10 @@ class KleinTestCase(unittest.TestCase):
         mock_kr.assert_called_with(app)
         mock_log.startLogging.assert_called_with(logFile)
 
-
-    @patch('klein._app.KleinResource')
-    @patch('klein._app.log')
-    @patch('klein._app.endpoints.serverFromString')
-    @patch('klein._app.reactor')
+    @patch("klein._app.KleinResource")
+    @patch("klein._app.log")
+    @patch("klein._app.endpoints.serverFromString")
+    @patch("klein._app.reactor")
     def test_runTCP6(self, reactor, mock_sfs, mock_log, mock_kr):
         """
         L{Klein.run} called with tcp6 endpoint description.
@@ -493,11 +484,10 @@ class KleinTestCase(unittest.TestCase):
         mock_log.startLogging.assert_called_with(sys.stdout)
         mock_kr.assert_called_with(app)
 
-
-    @patch('klein._app.KleinResource')
-    @patch('klein._app.log')
-    @patch('klein._app.endpoints.serverFromString')
-    @patch('klein._app.reactor')
+    @patch("klein._app.KleinResource")
+    @patch("klein._app.log")
+    @patch("klein._app.endpoints.serverFromString")
+    @patch("klein._app.reactor")
     def test_runSSL(self, reactor, mock_sfs, mock_log, mock_kr):
         """
         L{Klein.run} called with SSL endpoint specification.
@@ -514,8 +504,7 @@ class KleinTestCase(unittest.TestCase):
         mock_log.startLogging.assert_called_with(sys.stdout)
         mock_kr.assert_called_with(app)
 
-
-    @patch('klein._app.KleinResource')
+    @patch("klein._app.KleinResource")
     def test_resource(self, mock_kr):
         """
         L{Klien.resource} returns a L{KleinResource}.
@@ -526,59 +515,69 @@ class KleinTestCase(unittest.TestCase):
         mock_kr.assert_called_with(app)
         self.assertEqual(mock_kr.return_value, resource)
 
-
     def test_urlFor(self):
         """L{Klein.urlFor} builds an URL for an endpoint with parameters"""
 
         app = Klein()
 
-        @app.route('/user/<name>')
+        @app.route("/user/<name>")
         def userpage(req, name):
             return name
 
-        @app.route('/post/<int:postid>', endpoint='bar')
+        @app.route("/post/<int:postid>", endpoint="bar")
         def foo(req, postid):
             return str(postid)
 
-        request = requestMock(b'/user/john')
+        request = requestMock(b"/user/john")
         self.assertEqual(
-            app.execute_endpoint('userpage', request, 'john'),
-            'john'
+            app.execute_endpoint("userpage", request, "john"), "john"
         )
         self.assertEqual(
-            app.execute_endpoint('bar', requestMock(b'/post/123'), 123),
-            '123'
+            app.execute_endpoint("bar", requestMock(b"/post/123"), 123), "123"
         )
 
-        request = requestMock(b'/addr')
-        self.assertEqual(app.urlFor(request, 'userpage', {'name': 'john'}),
-                         '/user/john')
+        request = requestMock(b"/addr")
+        self.assertEqual(
+            app.urlFor(request, "userpage", {"name": "john"}), "/user/john"
+        )
 
-        request = requestMock(b'/addr')
-        self.assertEqual(app.urlFor(request, 'userpage', {'name': 'john'},
-                                    force_external=True),
-                         'http://localhost:8080/user/john')
+        request = requestMock(b"/addr")
+        self.assertEqual(
+            app.urlFor(
+                request, "userpage", {"name": "john"}, force_external=True
+            ),
+            "http://localhost:8080/user/john",
+        )
 
-        request = requestMock(b'/addr', host=b'example.com', port=4321)
-        self.assertEqual(app.urlFor(request, 'userpage', {'name': 'john'},
-                                    force_external=True),
-                         'http://example.com:4321/user/john')
+        request = requestMock(b"/addr", host=b"example.com", port=4321)
+        self.assertEqual(
+            app.urlFor(
+                request, "userpage", {"name": "john"}, force_external=True
+            ),
+            "http://example.com:4321/user/john",
+        )
 
-        request = requestMock(b'/addr')
-        url = app.urlFor(request, 'userpage', {'name': 'john', 'age': 29},
-                         append_unknown=True)
-        self.assertEqual(url, '/user/john?age=29')
+        request = requestMock(b"/addr")
+        url = app.urlFor(
+            request,
+            "userpage",
+            {"name": "john", "age": 29},
+            append_unknown=True,
+        )
+        self.assertEqual(url, "/user/john?age=29")
 
-        request = requestMock(b'/addr')
-        self.assertEqual(app.urlFor(request, 'bar', {'postid': 123}),
-                         '/post/123')
+        request = requestMock(b"/addr")
+        self.assertEqual(
+            app.urlFor(request, "bar", {"postid": 123}), "/post/123"
+        )
 
-        request = requestMock(b'/addr')
-        request.requestHeaders.removeHeader(b'host')
-        self.assertEqual(app.urlFor(request, 'bar', {'postid': 123}),
-                         '/post/123')
+        request = requestMock(b"/addr")
+        request.requestHeaders.removeHeader(b"host")
+        self.assertEqual(
+            app.urlFor(request, "bar", {"postid": 123}), "/post/123"
+        )
 
-        request = requestMock(b'/addr')
-        request.requestHeaders.removeHeader(b'host')
+        request = requestMock(b"/addr")
+        request.requestHeaders.removeHeader(b"host")
         with self.assertRaises(ValueError):
-            app.urlFor(request, 'bar', {'postid': 123}, force_external=True)
+            app.urlFor(request, "bar", {"postid": 123}, force_external=True)
