@@ -1,4 +1,4 @@
-# Copyright (c) 2017-2018. See LICENSE for details.
+# Copyright (c) 2011-2019. See LICENSE for details.
 
 """
 Tests for L{klein.test._trial}.
@@ -7,12 +7,12 @@ Tests for L{klein.test._trial}.
 from zope.interface import Interface, implementer
 
 from ._trial import TestCase
+from .._typing import ifmethod
 
 
 __all__ = ()
 
 
-
 class TestCaseTests(TestCase):
     """
     Tests for L{TestCase}.
@@ -22,30 +22,30 @@ class TestCaseTests(TestCase):
         """
         Frobbable object.
         """
+
+        @ifmethod
         def frob():
             # type: () -> None
             """
             Frob the object.
             """
 
-
     @implementer(IFrobbable)
     class Frobbable(object):
         """
         Implements L{IFrobbable}.
         """
+
         def frob(self):
             # type: () -> None
             pass
 
-
     @implementer(IFrobbable)
     class NotFrobbable(object):
         """
         Does not implement L{IFrobbable}, despite declaring.
         """
 
-
     def test_assertProvidesPass(self):
         # type: () -> None
         """
@@ -56,7 +56,6 @@ class TestCaseTests(TestCase):
         self.assertProvides(self.IFrobbable, frobbable)
         frobbable.frob()  # Coverage
 
-
     def test_assertProvidesFail(self):
         # type: () -> None
         """
@@ -65,5 +64,7 @@ class TestCaseTests(TestCase):
         """
         self.assertRaises(
             self.failureException,
-            self.assertProvides, self.IFrobbable, self.NotFrobbable(),
+            self.assertProvides,
+            self.IFrobbable,
+            self.NotFrobbable(),
         )
